## $Id: browser.py 8012 2012-03-30 17:55:44Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""UI components for basic applicants and related components.
"""
import grok
from waeup.kofa.widgets.datewidget import (
    FriendlyDateWidget, FriendlyDateDisplayWidget,
    FriendlyDatetimeDisplayWidget)
from waeup.kofa.widgets.phonewidget import PhoneWidget
from waeup.kofa.applicants.browser import (ApplicantDisplayFormPage,
    OnlinePaymentCallbackPage, ExportPDFPage, ApplicantManageFormPage)
from waeup.kofa.applicants.viewlets import RequestCallbackActionButton
from waeup.kofa.applicants.interfaces import IApplicant, IApplicantEdit
from waeup.custom.applicants.interfaces import IPGApplicant, IUGApplicant
from waeup.custom.interfaces import MessageFactory as _

class RequestCallbackActionButton(RequestCallbackActionButton):
    """ Do not display the base package callback button in custom pages.
    """
    @property
    def target_url(self):
        return ''

class OnlinePaymentCallbackPage(OnlinePaymentCallbackPage):
    """ Neutralize callback simulation view
    """
    def update(self):
        return

class ExportPDFPage(ExportPDFPage):
    """Deliver a PDF slip of the context.
    """
    grok.context(IApplicant)
    grok.name('application_slip.pdf')
    grok.require('waeup.viewApplication')
    form_fields = grok.AutoFields(IApplicant).omit(
        'locked', 'course_admitted')
    form_fields['date_of_birth'].custom_widget = FriendlyDateDisplayWidget('le')
    prefix = 'form'


class ApplicantDisplayFormPage(ApplicantDisplayFormPage):

    @property
    def form_fields(self):
        target = getattr(self.context.__parent__, 'prefix', None)
        if target is not None and target.startswith('pg'):
            form_fields = grok.AutoFields(IPGApplicant).omit(
                'locked', 'course_admitted', 'password')
        else:
            form_fields = grok.AutoFields(IUGApplicant).omit(
                'locked', 'course_admitted', 'password')
        form_fields['date_of_birth'].custom_widget = FriendlyDateDisplayWidget('le')
        return form_fields

class ApplicantManageFormPage(ApplicantManageFormPage):
    """A full edit view for applicant data.
    """
    grok.context(IApplicant)
    grok.name('manage')
    grok.require('waeup.manageApplication')
    form_fields = grok.AutoFields(IApplicant)
    form_fields['date_of_birth'].custom_widget = FriendlyDateWidget('le-year')
    form_fields['student_id'].for_display = True
    form_fields['applicant_id'].for_display = True
    form_fields['phone'].custom_widget = PhoneWidget
    grok.template('applicanteditpage')
    manage_applications = True
    pnav = 3
    display_actions = [[_('Save'), _('Final Submit')],
        [_('Add online payment ticket'),_('Remove selected tickets')]]


class ApplicantEditFormPage(ApplicantManageFormPage):
    """An applicant-centered edit view for applicant data.
    """
    grok.context(IApplicantEdit)
    grok.name('edit')
    grok.require('waeup.handleApplication')
    form_fields = grok.AutoFields(IApplicantEdit).omit(
        'locked', 'course_admitted', 'student_id',
        'screening_score', 'reg_number'
        )
    form_fields['date_of_birth'].custom_widget = FriendlyDateWidget('le-year')
    form_fields['phone'].custom_widget = PhoneWidget
    form_fields['applicant_id'].for_display = True
    grok.template('applicanteditpage')
    manage_applications = False
